@@ -122,7 +122,7 @@ echo "- Select a container and connect to access the terminal"
 echo ""
 echo "Troubleshooting:"
 echo "- Check terminal server logs: journalctl -u whp-terminal -f"
-echo "- Verify WebSocket proxy: curl -I http://localhost/terminal-ws"
+echo "- Verify WebSocket proxy: curl -I http://localhost:8080/terminal-ws"
 echo "- Check xterm.js files: ls -la /docker/whp/web/js/xterm/"
 echo ""
 echo "If you encounter issues, restart the services:"
