@@ -188,6 +188,7 @@ $stats = [
                                 <label for="siteSelection" class="form-label">Select Site</label>
                                 <select class="form-select" id="siteSelection">
                                     <option value="">Select Site</option>
+                                    <option value="*">All Sites</option>
                                     <?php foreach ($sites as $site): ?>
                                     <option value="<?php echo htmlspecialchars($site); ?>"><?php echo htmlspecialchars($site); ?></option>
                                     <?php endforeach; ?>
@@ -197,6 +198,7 @@ $stats = [
                                 <label for="dbSelection" class="form-label">Select Database</label>
                                 <select class="form-select" id="dbSelection">
                                     <option value="">Select Database</option>
+                                    <option value="*">All Databases</option>
                                     <?php foreach ($databases as $db): ?>
                                     <option value="<?php echo htmlspecialchars($db); ?>"><?php echo htmlspecialchars($db); ?></option>
                                     <?php endforeach; ?>
@@ -391,19 +393,65 @@ $stats = [
         </div>
     </div>
 
-    <!-- Recent Backups Section -->
+    <!-- All Backups Section -->
     <div class="row">
         <div class="col-12">
             <div class="card">
                 <div class="card-header">
                     <div class="d-flex justify-content-between align-items-center">
-                        <h5><i class="fa fa-history"></i> Recent Backups</h5>
+                        <h5><i class="fa fa-history"></i> All Backups</h5>
                         <small class="text-muted">
                             <i class="fa fa-clock-o"></i> Times shown in your local timezone
                         </small>
                     </div>
                 </div>
                 <div class="card-body">
+                    <!-- Search and Filter Bar -->
+                    <div class="row mb-3">
+                        <div class="col-md-3">
+                            <input type="text" class="form-control" id="backupSearch" placeholder="Search backup name...">
+                        </div>
+                        <?php if ($isRoot): ?>
+                        <div class="col-md-2">
+                            <select class="form-select" id="backupUserFilter">
+                                <option value="">All Users</option>
+                                <?php foreach ($allUsers as $user): ?>
+                                <option value="<?php echo htmlspecialchars($user); ?>"><?php echo htmlspecialchars($user); ?></option>
+                                <?php endforeach; ?>
+                            </select>
+                        </div>
+                        <?php endif; ?>
+                        <div class="col-md-2">
+                            <select class="form-select" id="backupTypeFilter">
+                                <option value="">All Types</option>
+                                <option value="site">Site</option>
+                                <option value="userfiles">User Files</option>
+                                <option value="database">Database</option>
+                            </select>
+                        </div>
+                        <div class="col-md-2">
+                            <select class="form-select" id="backupStatusFilter">
+                                <option value="">All Status</option>
+                                <option value="completed">Completed</option>
+                                <option value="running">Running</option>
+                                <option value="failed">Failed</option>
+                                <option value="pending">Pending</option>
+                            </select>
+                        </div>
+                        <div class="col-md-2">
+                            <select class="form-select" id="backupLimitFilter">
+                                <option value="20">20 per page</option>
+                                <option value="50" selected>50 per page</option>
+                                <option value="100">100 per page</option>
+                                <option value="200">200 per page</option>
+                            </select>
+                        </div>
+                        <div class="col-md-1">
+                            <button class="btn btn-primary w-100" onclick="loadBackups(1)">Search</button>
+                        </div>
+                    </div>
+                    
+                    <!-- Backup Table -->
                     <div class="table-responsive">
                         <table class="table table-hover">
                             <thead>
@@ -419,44 +467,20 @@ $stats = [
                                 </tr>
                             </thead>
                             <tbody id="backupsList">
-                                <?php foreach ($recentBackups as $backup): ?>
-                                <tr>
-                                    <td><?php echo htmlspecialchars($backup['backup_name']); ?></td>
-                                    <td>
-                                        <span class="badge bg-<?php echo getBackupTypeColor($backup['backup_type']); ?>">
-                                            <?php echo ucfirst($backup['backup_type']); ?>
-                                        </span>
-                                    </td>
-                                    <td><?php echo htmlspecialchars($backup['user']); ?></td>
-                                    <td><?php echo htmlspecialchars($backup['target_name']); ?></td>
-                                    <td><?php echo formatBytes($backup['backup_size']); ?></td>
-                                    <td>
-                                        <span class="badge bg-<?php echo getStatusColor($backup['status']); ?>">
-                                            <?php echo ucfirst($backup['status']); ?>
-                                        </span>
-                                    </td>
-                                    <td>
-                                        <span class="local-time" data-utc="<?php echo date('c', strtotime($backup['started_at'])); ?>">
-                                            <?php echo date('Y-m-d H:i:s', strtotime($backup['started_at'])); ?>
-                                        </span>
-                                    </td>
-                                    <td>
-                                        <?php if ($backup['status'] === 'completed'): ?>
-                                        <button class="btn btn-sm btn-outline-success" onclick="downloadBackup(<?php echo $backup['id']; ?>)">
-                                            <i class="fa fa-download"></i> Download
-                                        </button>
-                                        <?php endif; ?>
-                                        <?php if ($isRoot || $backup['user'] === AUTH_USER): ?>
-                                        <button class="btn btn-sm btn-outline-danger" onclick="deleteBackup(<?php echo $backup['id']; ?>)">
-                                            <i class="fa fa-trash"></i> Delete
-                                        </button>
-                                        <?php endif; ?>
-                                    </td>
-                                </tr>
-                                <?php endforeach; ?>
+                                <!-- Will be populated by JavaScript -->
                             </tbody>
                         </table>
                     </div>
+                    
+                    <!-- Pagination -->
+                    <div class="d-flex justify-content-between align-items-center mt-3">
+                        <div id="backupInfo"></div>
+                        <nav>
+                            <ul class="pagination mb-0" id="backupPagination">
+                                <!-- Will be populated by JavaScript -->
+                            </ul>
+                        </nav>
+                    </div>
                 </div>
             </div>
         </div>
@@ -522,8 +546,9 @@ $stats = [
                             <input type="number" class="form-control" id="targetRetention" name="retention_days" value="30" min="1">
                         </div>
                         <div class="col-md-6">
-                            <label for="targetMaxBackups" class="form-label">Max Backups</label>
+                            <label for="targetMaxBackups" class="form-label">Max Backups <span id="maxBackupsHint"></span></label>
                             <input type="number" class="form-control" id="targetMaxBackups" name="max_backups" value="10" min="1">
+                            <small class="form-text text-muted" id="maxBackupsHelp">Maximum backups to keep per backup type</small>
                         </div>
                     </div>
                     <?php if ($isRoot): ?>
@@ -584,8 +609,8 @@ $stats = [
                     <div class="row mt-3">
                         <div class="col-md-6">
                             <label for="scheduleResource" class="form-label">Resource Name</label>
-                            <input type="text" class="form-control" id="scheduleResource" name="resource_name" placeholder="Leave blank for all">
-                            <small class="form-text text-muted">For sites: domain name, for databases: database name</small>
+                            <input type="text" class="form-control" id="scheduleResource" name="resource_name" placeholder="Leave blank for first available">
+                            <small class="form-text text-muted">For sites: domain name, for databases: database name. Use * for all resources.</small>
                         </div>
                         <div class="col-md-6">
                             <label for="scheduleTarget" class="form-label">Backup Target</label>
@@ -648,7 +673,7 @@ $stats = [
 
 <script>
 // Define CSRF token for AJAX requests
-const nonce = '<?php echo get_csrf_token(); ?>';
+const csrfToken = '<?php echo get_csrf_token(); ?>';
 
 // Show/hide selection fields based on backup type
 document.getElementById('backupType').addEventListener('change', function() {
@@ -690,7 +715,7 @@ document.getElementById('backupForm').addEventListener('submit', function(e) {
     fetch('api/backup-actions.php', {
         method: 'POST',
         headers: {
-            'X-CSRF-Token': nonce
+            'X-CSRF-Token': csrfToken
         },
         body: formData
     })
@@ -719,7 +744,7 @@ document.getElementById('targetForm').addEventListener('submit', function(e) {
     fetch('api/backup-actions.php', {
         method: 'POST',
         headers: {
-            'X-CSRF-Token': nonce
+            'X-CSRF-Token': csrfToken
         },
         body: formData
     })
@@ -744,8 +769,9 @@ function testTarget(targetId) {
         method: 'POST',
         headers: {
             'Content-Type': 'application/x-www-form-urlencoded',
+            'X-CSRF-Token': csrfToken
         },
-        body: `action=test_target&target_id=${targetId}&csrf_token=<?php echo get_csrf_token(); ?>`
+        body: `action=test_target&target_id=${targetId}`
     })
     .then(response => response.json())
     .then(data => {
@@ -767,7 +793,7 @@ function deleteBackup(backupId) {
             method: 'POST',
             headers: {
                 'Content-Type': 'application/x-www-form-urlencoded',
-                'X-CSRF-Token': nonce
+                'X-CSRF-Token': csrfToken
             },
             body: `action=delete_backup&backup_id=${backupId}`
         })
@@ -828,7 +854,7 @@ function deleteTarget(targetId) {
             method: 'POST',
             headers: {
                 'Content-Type': 'application/x-www-form-urlencoded',
-                'X-CSRF-Token': nonce
+                'X-CSRF-Token': csrfToken
             },
             body: `action=delete_target&target_id=${targetId}`
         })
@@ -904,6 +930,9 @@ document.getElementById('scheduleForm').addEventListener('submit', function(e) {
     
     fetch('api/backup-actions.php', {
         method: 'POST',
+        headers: {
+            'X-CSRF-Token': csrfToken
+        },
         body: formData
     })
     .then(response => response.json())
@@ -999,7 +1028,7 @@ function testSchedule(scheduleId) {
             method: 'POST',
             headers: {
                 'Content-Type': 'application/x-www-form-urlencoded',
-                'X-CSRF-Token': nonce
+                'X-CSRF-Token': csrfToken
             },
             body: `action=test_schedule&schedule_id=${scheduleId}`
         })
@@ -1024,7 +1053,7 @@ function deleteSchedule(scheduleId) {
             method: 'POST',
             headers: {
                 'Content-Type': 'application/x-www-form-urlencoded',
-                'X-CSRF-Token': nonce
+                'X-CSRF-Token': csrfToken
             },
             body: `action=delete_schedule&schedule_id=${scheduleId}`
         })
@@ -1067,7 +1096,7 @@ function runSchedulerNow() {
             method: 'POST',
             headers: {
                 'Content-Type': 'application/x-www-form-urlencoded',
-                'X-CSRF-Token': nonce
+                'X-CSRF-Token': csrfToken
             },
             body: `action=run_scheduler`
         })
@@ -1134,7 +1163,234 @@ function convertToLocalTime() {
 }
 
 // Convert times when page loads
-document.addEventListener('DOMContentLoaded', convertToLocalTime);
+document.addEventListener('DOMContentLoaded', function() {
+    convertToLocalTime();
+    loadBackups(1); // Load first page of backups
+});
+
+// Pagination and search functionality
+let currentPage = 1;
+let totalPages = 1;
+let totalBackups = 0;
+
+function loadBackups(page = 1) {
+    currentPage = page;
+    
+    const searchTerm = document.getElementById('backupSearch').value;
+    const userFilter = document.getElementById('backupUserFilter')?.value || '';
+    const typeFilter = document.getElementById('backupTypeFilter').value;
+    const statusFilter = document.getElementById('backupStatusFilter').value;
+    const limit = document.getElementById('backupLimitFilter').value;
+    const offset = (page - 1) * limit;
+    
+    // Build query parameters
+    const params = new URLSearchParams({
+        action: 'list_backups',
+        limit: limit,
+        offset: offset
+    });
+    
+    if (searchTerm) params.append('search', searchTerm);
+    if (userFilter) params.append('user', userFilter);
+    if (typeFilter) params.append('backup_type', typeFilter);
+    if (statusFilter) params.append('status', statusFilter);
+    
+    // Show loading indicator
+    document.getElementById('backupsList').innerHTML = '<tr><td colspan="8" class="text-center"><i class="fa fa-spinner fa-spin"></i> Loading backups...</td></tr>';
+    
+    fetch('api/backup-actions.php?' + params.toString())
+        .then(response => response.json())
+        .then(data => {
+            if (data.success) {
+                totalBackups = data.total;
+                totalPages = Math.ceil(totalBackups / limit);
+                displayBackups(data.backups);
+                updatePagination();
+                updateBackupInfo(offset, limit);
+            } else {
+                showAlert('Error loading backups: ' + data.message, 'danger');
+            }
+        })
+        .catch(error => {
+            showAlert('Error loading backups: ' + error.message, 'danger');
+        });
+}
+
+function displayBackups(backups) {
+    const tbody = document.getElementById('backupsList');
+    
+    if (backups.length === 0) {
+        tbody.innerHTML = '<tr><td colspan="8" class="text-center text-muted">No backups found</td></tr>';
+        return;
+    }
+    
+    tbody.innerHTML = backups.map(backup => `
+        <tr>
+            <td>${escapeHtml(backup.backup_name)}</td>
+            <td>
+                <span class="badge bg-${getBackupTypeColorJS(backup.backup_type)}">
+                    ${backup.backup_type.charAt(0).toUpperCase() + backup.backup_type.slice(1)}
+                </span>
+            </td>
+            <td>${escapeHtml(backup.user)}</td>
+            <td>${escapeHtml(backup.target_name)}</td>
+            <td>${formatBytesJS(backup.backup_size)}</td>
+            <td>
+                <span class="badge bg-${getStatusColorJS(backup.status)}">
+                    ${backup.status.charAt(0).toUpperCase() + backup.status.slice(1)}
+                </span>
+            </td>
+            <td>
+                <span class="local-time" data-utc="${new Date(backup.started_at).toISOString()}">
+                    ${backup.started_at}
+                </span>
+            </td>
+            <td>
+                ${backup.status === 'completed' ? `
+                    <button class="btn btn-sm btn-outline-success" onclick="downloadBackup(${backup.id})">
+                        <i class="fa fa-download"></i> Download
+                    </button>
+                ` : ''}
+                ${<?php echo $isRoot ? 'true' : 'false'; ?> || backup.user === '<?php echo AUTH_USER; ?>' ? `
+                    <button class="btn btn-sm btn-outline-danger" onclick="deleteBackup(${backup.id})">
+                        <i class="fa fa-trash"></i> Delete
+                    </button>
+                ` : ''}
+            </td>
+        </tr>
+    `).join('');
+    
+    // Convert times to local
+    convertToLocalTime();
+}
+
+function updatePagination() {
+    const pagination = document.getElementById('backupPagination');
+    const pages = [];
+    
+    // Previous button
+    pages.push(`
+        <li class="page-item ${currentPage === 1 ? 'disabled' : ''}">
+            <a class="page-link" href="#" onclick="loadBackups(${currentPage - 1}); return false;">Previous</a>
+        </li>
+    `);
+    
+    // Calculate page range
+    let startPage = Math.max(1, currentPage - 2);
+    let endPage = Math.min(totalPages, currentPage + 2);
+    
+    // First page if not in range
+    if (startPage > 1) {
+        pages.push(`
+            <li class="page-item">
+                <a class="page-link" href="#" onclick="loadBackups(1); return false;">1</a>
+            </li>
+        `);
+        if (startPage > 2) {
+            pages.push(`<li class="page-item disabled"><span class="page-link">...</span></li>`);
+        }
+    }
+    
+    // Page numbers
+    for (let i = startPage; i <= endPage; i++) {
+        pages.push(`
+            <li class="page-item ${i === currentPage ? 'active' : ''}">
+                <a class="page-link" href="#" onclick="loadBackups(${i}); return false;">${i}</a>
+            </li>
+        `);
+    }
+    
+    // Last page if not in range
+    if (endPage < totalPages) {
+        if (endPage < totalPages - 1) {
+            pages.push(`<li class="page-item disabled"><span class="page-link">...</span></li>`);
+        }
+        pages.push(`
+            <li class="page-item">
+                <a class="page-link" href="#" onclick="loadBackups(${totalPages}); return false;">${totalPages}</a>
+            </li>
+        `);
+    }
+    
+    // Next button
+    pages.push(`
+        <li class="page-item ${currentPage === totalPages ? 'disabled' : ''}">
+            <a class="page-link" href="#" onclick="loadBackups(${currentPage + 1}); return false;">Next</a>
+        </li>
+    `);
+    
+    pagination.innerHTML = pages.join('');
+}
+
+function updateBackupInfo(offset, limit) {
+    const info = document.getElementById('backupInfo');
+    const start = offset + 1;
+    const end = Math.min(offset + parseInt(limit), totalBackups);
+    
+    if (totalBackups === 0) {
+        info.textContent = 'No backups found';
+    } else {
+        info.textContent = `Showing ${start} to ${end} of ${totalBackups} backups`;
+    }
+}
+
+// Helper functions
+function escapeHtml(text) {
+    const div = document.createElement('div');
+    div.textContent = text;
+    return div.innerHTML;
+}
+
+function getBackupTypeColorJS(type) {
+    switch (type) {
+        case 'site': return 'primary';
+        case 'userfiles': return 'info';
+        case 'database': return 'warning';
+        default: return 'secondary';
+    }
+}
+
+function getStatusColorJS(status) {
+    switch (status) {
+        case 'completed': return 'success';
+        case 'running': return 'warning';
+        case 'failed': return 'danger';
+        case 'pending': return 'info';
+        default: return 'secondary';
+    }
+}
+
+function formatBytesJS(bytes, precision = 2) {
+    const units = ['B', 'KB', 'MB', 'GB', 'TB'];
+    
+    for (let i = 0; bytes > 1024 && i < units.length - 1; i++) {
+        bytes /= 1024;
+    }
+    
+    return bytes.toFixed(precision) + ' ' + units[Math.max(0, Math.min(units.length - 1, Math.floor(Math.log(bytes) / Math.log(1024))))];
+}
+
+// Search on enter key
+document.getElementById('backupSearch').addEventListener('keypress', function(e) {
+    if (e.key === 'Enter') {
+        loadBackups(1);
+    }
+});
+
+// Update help text for global targets
+<?php if ($isRoot): ?>
+document.getElementById('targetGlobal').addEventListener('change', function() {
+    const helpText = document.getElementById('maxBackupsHelp');
+    const hintText = document.getElementById('maxBackupsHint');
+    if (this.checked) {
+        helpText.textContent = 'Maximum backups to keep per user, per backup type';
+        hintText.textContent = '(Per User)';
+    } else {
+        helpText.textContent = 'Maximum backups to keep per backup type';
+        hintText.textContent = '';
+    }
+});
+<?php endif; ?>
 </script>
 
 <?php
